package betterquesting.api2.client.gui.resources.textures;

import betterquesting.api2.client.gui.misc.IGuiRect;
import betterquesting.api2.client.gui.resources.colors.IGuiColor;
import net.minecraft.util.ResourceLocation;

/* loaded from: betterquesting_api2_client_gui_resources_textures.jar:betterquesting/api2/client/gui/resources/textures/LayeredTexture.class */
public class LayeredTexture implements IGuiTexture {
    private final IGuiTexture[] layers;

    public LayeredTexture(IGuiTexture... layers) {
        this.layers = layers;
    }

    @Override // betterquesting.api2.client.gui.resources.textures.IGuiTexture
    public void drawTexture(int x, int y, int width, int height, float zDepth, float partialTick) {
        if (width <= 0 || height <= 0) {
            return;
        }
        for (IGuiTexture tex : this.layers) {
            tex.drawTexture(x, y, width, height, zDepth, partialTick);
        }
    }

    @Override // betterquesting.api2.client.gui.resources.textures.IGuiTexture
    public void drawTexture(int x, int y, int width, int height, float zDepth, float partialTick, IGuiColor color) {
        if (width <= 0 || height <= 0) {
            return;
        }
        for (IGuiTexture tex : this.layers) {
            tex.drawTexture(x, y, width, height, zDepth, partialTick, color);
        }
    }

    @Override // betterquesting.api2.client.gui.resources.textures.IGuiTexture
    public ResourceLocation getTexture() {
        if (this.layers.length <= 0) {
            return null;
        }
        return this.layers[0].getTexture();
    }

    @Override // betterquesting.api2.client.gui.resources.textures.IGuiTexture
    public IGuiRect getBounds() {
        if (this.layers.length <= 0) {
            return null;
        }
        return this.layers[0].getBounds();
    }
}
